bayespy.nodes.GaussianGammaISO.get_gaussian_mean_and_variance
=============================================================

.. currentmodule:: bayespy.nodes

.. automethod:: GaussianGammaISO.get_gaussian_mean_and_variance